@@ -32,7 +32,8 @@ class BrowserV2:
             rotative_agent: bool = False,
             version_main: str = None,
             use_profile: bool = False,
-            use_headless: bool = False
+            use_headless: bool = False,
+            download_path: str = None
     ) -> None:
 
         self.__version_main = version_main
@@ -40,6 +41,7 @@ class BrowserV2:
         self.__rotative_agent = rotative_agent
         self.__use_profile = use_profile
         self.__use_headless = use_headless
+        self.__download_path = download_path
         BrowserV2.__options = uc.ChromeOptions()
 
         if (profile_path is not None) and (use_profile is False):
@@ -55,6 +57,10 @@ class BrowserV2:
         BrowserV2.user_agents = list(Utils.get_agent_users())
         if self.__use_headless:
             BrowserV2.__options.add_argument('--headless')
+
+        if self.__download_path:
+            BrowserV2.__options.add_experimental_option("prefs", {'download.default_directory': self.__download_path})
+
         # just some options passing in to skip annoying popups
         BrowserV2.__options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
         BrowserV2.__options.add_argument('--start-maximized')
@@ -148,6 +154,18 @@ class BrowserV2:
     def wait_new_tab(self, time=10, number_tabs=2):
         WebDriverWait(self.driver, time).until(EC.number_of_windows_to_be(number_tabs))
 
+    def wait_tab_with_title(self, title, time=10):
+        WebDriverWait(self.driver, time).until(EC.title_contains(title))
+
+    def wait_tab_with_url(self, url, time=10):
+        WebDriverWait(self.driver, time).until(EC.url_contains(url))
+
+    def change_recent_tab(self, original_tab):
+        for window_handle in self.driver.window_handles:
+            if window_handle != original_tab:
+                self.driver.switch_to.window(window_handle)
+                break
+
 
 class ChecksBypass(BrowserV2):
     def __init__(self, profile_path=None, rotative_agent=None, active_sleep=False):
